[X2Go-Commits] x2goserver.git - release/4.0.1.x (branch) updated: 3.0.99-2-195-g74cb4ab

X2Go dev team git-admin at x2go.org
Thu Jun 6 13:34:44 CEST 2013


The branch, release/4.0.1.x has been updated
       via  74cb4ab793b6e59aad8497f7facec9deb20be6ce (commit)
      from  6957a368ee4202a90be8c844173196660ad5a8c5 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
-----------------------------------------------------------------------

Summary of changes:
 debian/changelog                                |    1 +
 x2goserver/{bin/x2goprint => lib/x2goprint.pl}  |    0
 x2goserver/{x2gosqlitewrapper.c => x2goprint.c} |   10 +++++-----
 3 files changed, 6 insertions(+), 5 deletions(-)
 rename x2goserver/{bin/x2goprint => lib/x2goprint.pl} (100%)
 copy x2goserver/{x2gosqlitewrapper.c => x2goprint.c} (86%)

The diff of changes is:
diff --git a/debian/changelog b/debian/changelog
index 49e30f7..2739a45 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -34,6 +34,7 @@ x2goserver (3.0.99.5-0~x2go3) UNRELEASED; urgency=low
   * Silence x2golistsessions on missing session.log files.
   * Create x2goprint user/group on package installation, add same info to INSTALL howto.
   * Change permissions on x2goprint, using 2755:root:x2goprint (setgid).
+  * Change X2go printing concept: use setgit and a sgid wrapper instead of sudo.
 
   [Martin Oehler]
   * Removes old debug code fragment, fixes x2golistsessions parsing.
diff --git a/x2goserver/bin/x2goprint b/x2goserver/lib/x2goprint.pl
similarity index 100%
rename from x2goserver/bin/x2goprint
rename to x2goserver/lib/x2goprint.pl
diff --git a/x2goserver/x2gosqlitewrapper.c b/x2goserver/x2goprint.c
similarity index 86%
copy from x2goserver/x2gosqlitewrapper.c
copy to x2goserver/x2goprint.c
index 95e2a8a..8f177ca 100644
--- a/x2goserver/x2gosqlitewrapper.c
+++ b/x2goserver/x2goprint.c
@@ -31,7 +31,7 @@
 
 
 int main( int argc, char *argv[] ) {
-	char * x2gosqlitewrapper = NULL;
+	char * x2goprint = NULL;
 	size_t path_max;
 	
 /*
@@ -63,8 +63,8 @@ int main( int argc, char *argv[] ) {
 		}
 
 
-		// derive the full path of x2gosqlitewrapper.pl from path of this binary
-		rvap = asprintf(&x2gosqlitewrapper, "%s/%s", dirname(buffer), "x2gosqlitewrapper.pl");
+		// derive the full path of x2goprint.pl from path of this binary
+		rvap = asprintf(&x2goprint, "%s/../lib/x2go/%s", dirname(buffer), "x2goprint.pl");
 		if(rvap == -1){
 			fprintf(stderr, "Failed to allocate memory calling asprintf\n");
 			exit(EXIT_FAILURE);
@@ -72,12 +72,12 @@ int main( int argc, char *argv[] ) {
 
 
 		// execute the script, running with user-rights of this binary 
-		execv(x2gosqlitewrapper, argv);
+		execv(x2goprint, argv);
 
 	}
 
 	// ...fail
-	fprintf(stderr, "Failed to execute %s: %s\n", x2gosqlitewrapper, strerror(errno));
+	fprintf(stderr, "Failed to execute %s: %s\n", x2goprint, strerror(errno));
 	return EXIT_FAILURE;
 
 }


hooks/post-receive
-- 
x2goserver.git (X2Go Server)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "x2goserver.git" (X2Go Server).




More information about the x2go-commits mailing list